#
# spec file for package python-pymisp
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{!?license: %global license %doc}
%bcond_without test
Name:           python-pymisp
Version:        2.4.87.1
Release:        lp151.2.4
Summary:        Python API for MISP
License:        BSD-2-Clause
Group:          Development/Languages/Python
Url:            https://github.com/MISP/PyMISP
Source:         https://files.pythonhosted.org/packages/source/p/pymisp/pymisp-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module jsonschema}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module python-magic}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  %{python_module requests}
%endif
# SECTION docs
BuildRequires:  python3-CommonMark
BuildRequires:  python3-Sphinx
BuildRequires:  python3-recommonmark
# /SECTION
Requires:       python-jsonschema
Requires:       python-python-dateutil
Requires:       python-requests
Recommends:     %{name}-doc
Recommends:     python-magic
Suggests:       python-pydeep
BuildArch:      noarch

%python_subpackages

%package -n %{name}-doc
Summary:        Examples and Documentation for %{name}
Group:          Documentation/HTML

%description
PyMISP is a Python library to access MISP platforms via their REST API.

PyMISP allows you to fetch events, add or update events/attributes, add or update samples or search for attributes.

%description -n %{name}-doc
Examples and HTML documentation for %{name}.

%prep
%setup -q -n pymisp-%{version}
find pymisp examples -name "*.py" -type f -exec sed -i '1s/^#!.*//' '{}' \+

%build
%python_build
pushd docs
export LANG=en_US.UTF-8
make html
rm build/html/.buildinfo
popd

%install
%python_install
%{python_expand %fdupes %{buildroot}%{$python_sitelib}}

%if %{with test}
%check
# Requires internet access and a MISP-instance
rm tests/test.py
%python_exec setup.py test
%endif

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/*

%files -n %{name}-doc
%doc examples docs/build/html

%changelog
* Tue Feb 13 2018 sebix+novell.com@sebix.at
- update to version 2.4.87.1:
  - APIs to manage sharing groups. (#185)
  - ReturnMetaAttributes flag for freeTextImport API. (#188)
  - Encode string in _encode_file_to_upload.
  - Prevent unpublished events to be included in feed.
  Change default proposed config
- remove patch fix-Encode_string_in__encode_file_to_upload.patch, included upstream
* Tue Jan 30 2018 sebix+novell.com@sebix.at
- update to version 2.4.87:
  - Add bindings for Galaxies and Taxonimies.
  - Add bindings to PyMISPWarninglists.
  - Raise an exception when distribution is sharing group, but the ID is
  missing.
  - Allow to pass a directory with custom object templates.
  - Allow to pass value, UUID, or ID to a sighting.
  - Add_hashes was broken. (#174)
  - Add: Allow to fetch warninglists. (#180)
- Add fix-Encode_string_in__encode_file_to_upload.patch to fix encoding problem (#183)
* Fri Dec 22 2017 sebix+novell.com@sebix.at
- update to version 2.4.85:
  - Add last field to get_csv.
  - Validate attributes in attributes.setter.
  - Add get_attribute_tag method at MISPEvent level.
  Also add a MISPTag class for consistency.
  - Use new format for filtering.
  - Initialize default class parameters. (#155)
  - Fix MISPObject missing distribution and sharing_group_id.
  - fix MISPObject missing distribution concept
  - fix language typo paramaters => parameters
  - Include documentation and examples in source dist.
* Wed Dec 13 2017 sebix+novell.com@sebix.at
- update to version 2.4.84
  - Add methods to get taxonomy(ies)
  - Add method to get all the events modified in an interval.
  - Allow to pass a pseudofile to LIEF.
  - Correction for 'last' param. 'last' gives the latest events that
  have been published - add get_events_last_modified() this function
  returns the modified events based on timestamp.
* Thu Dec  7 2017 sebix+novell.com@sebix.at
- update to version 2.4.83
  - Add get CSV method.
  - Allow to pass a proxy to query VT.
  - Do not get the event from the server before publishing if
  PyMISP.publish gets an ID.
  - Add a way to check if the ACL is up-to-date.
  - Add validators for describeTypes on the live instance.
  - Add new objects: MISPUser and MISPOrganisation.
  - Add a generic MISP object generator.
  - Allow to add multiple attribute of the same type.
  - Add fast publish method. Fix #86
* Fri Nov 10 2017 sebix+novell.com@sebix.at
- update to version 2.4.82
  - Proper debug system.
  - Changes
  - Small improvments in the logging system using python logging module.
  - Let load unknown object relations in known templates.
  - Allow to load non-malware ZIP files in MISP Event.
  - Properly pass the distribution when uploading a sample.
  - Other
  - Created add_generic_object.py.
- remove patch fix-offline-test.patch, included in upstream version
- shorten existing changelogs
* Thu Oct 26 2017 sebix+novell.com@sebix.at
- update to version 2.4.81.2
- update to version 2.4.81.1:
  - Allow to hard delete an attribute by ID.
  - Fixes
  - Improve dependencies listing. Partial fix for #110
  - Missing default category. Fix #119
- add fix-offline-test.patch to fix tests
* Mon Oct  9 2017 sebix+novell.com@sebix.at
- update to version 2.4.81
* Wed Oct  4 2017 sebix+novell.com@sebix.at
- update to version 2.4.80.1
  - Fix
  - Allow again to tag/delete unsaved attributes.
  - Import the openioc converter from tool again.
  - Other
  - Fixing #114 (MISPEvent.add_tag(tag) fails if inital event does not contain tag )
  - Formatted "Unknown MISP object" error message.
- removed fix-tests-pr-111.patch, merged upstream
* Wed Sep 20 2017 sebix+novell.com@sebix.at
- update to version 2.4.80
  - Allow to get the list of known types out of MISPEvent again.
  - Changed two fields in object references.
  - source_uuid => object_uuid
  - destination_uuid => referenced_uuid
  - Refactoring in order to load objects.
  - Add support for multiple entries of the same type in an object.
  - Add support for ELF and MachO objects.
- add fix-tests-pr-111.patch to skip an optional test depending on third party data
* Thu Sep  7 2017 sebix+novell.com@sebix.at
- update to version 2.4.79
- updated shebang fixes
* Wed Aug 10 2016 sebix+novell.com@sebix.at
- inital package
